pub struct BinanceSpotWsTradingHandler { /* private fields */ }Expand description
Binance Spot WebSocket API handler.
Runs in a dedicated Tokio task, processing commands from the client and transforming raw WebSocket messages into Nautilus domain events. Messages are sent to the client via the output channel.
Implementations
Sourceimpl BinanceSpotWsTradingHandler
impl BinanceSpotWsTradingHandler
Sourcepub fn new(
signal: Arc<AtomicBool>,
cmd_rx: UnboundedReceiver<BinanceSpotWsTradingCommand>,
raw_rx: UnboundedReceiver<Message>,
out_tx: UnboundedSender<BinanceSpotWsTradingMessage>,
credential: Arc<SigningCredential>,
) -> Self
pub fn new( signal: Arc<AtomicBool>, cmd_rx: UnboundedReceiver<BinanceSpotWsTradingCommand>, raw_rx: UnboundedReceiver<Message>, out_tx: UnboundedSender<BinanceSpotWsTradingMessage>, credential: Arc<SigningCredential>, ) -> Self
Creates a new handler instance.